package com.muyu.etl.data.access.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.etl.data.access.domain.req.DataSourceUpdReq;
import com.muyu.etl.data.access.pool.base.BaseConfig;
import jakarta.validation.constraints.NotEmpty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/8/19 19:04
 * @注释
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
@EqualsAndHashCode(callSuper = true)
@TableName(value = "etl_database_source",autoResultMap = true)
public class DataSource extends BaseEntity {

    /**
     * 主键
     */
    @TableId(value = "id",type = IdType.AUTO)
    private Long id;
    /**
     *数据源类型 mysql
     */
    @NotEmpty(message = "数据源类型不可为空")
    private String   databaseType;
    /**
     *数据源名称  jdbc:mysql://localhost:3306/dbname?useUnicode=true&serverTimezone=Asia/Shanghai
     */
    private String databaseFormName;
    /**
     *数据来源IP 127.0.0.1
     */
    @NotEmpty(message = "数据来源IP 不可为空")

    private String databaseUrl;
    /**
     *来源地址端口号 3306
     */
    @NotEmpty(message = "来源地址端口号不可为空")

    private String databasePost;
    /**
     *数据库名称 cloud-server
     */
    @NotEmpty(message = "数据库名称不可为空")

    private String databaseName;
    /**
     *数据库登录名 root
     */
    @NotEmpty(message = "数据库登录名不可为空")

    private String userName;
    /**
     *数据库登录密码 123
     */
    @NotEmpty(message = "数据库登录密码型不可为空")
    private String userPwd;
    /**
     *数据源状态(1启用,2禁用)
     */
    private String status;
    /** 驱动 com.mysql.cj.jdbc.Driver */
    private String driverName;

    /** 初始连接数量 */
    private Integer initCount;

    /** 最大连接数量 */
    private Integer maxCount;

    /** 最大等待时间 */
    private Integer maxTime;

    /** 最大等待次数 */
    private Integer maxFrequency;

    /**
     * 获取数据库连接
     * @return
     */
    public String getUrl(DataSource dataSource){

        StringBuilder urlSb = new StringBuilder(BaseConfig.MYSQLJDBCPRO);
        urlSb.append(dataSource.databaseUrl);//拼接ip
        urlSb.append(":");
        urlSb.append(dataSource.databasePost); //拼接端口
        urlSb.append("/");
        urlSb.append(dataSource.databaseName);//拼接数据库
        urlSb.append("?");
        urlSb.append(dataSource.databaseFormName);//useUnicode=true&characterEncoding=utf8&zeroDateTimeBehavior=convertToNull&useSSL=true&serverTimezone=GMT%2B8
        return urlSb.toString();
    }



    public static  DataSource updBuild(Long id, DataSourceUpdReq req){
        return DataSource.builder()
                .id(id)
                .databaseFormName(req.getDatabaseFormName())
                .databaseType(req.getDatabaseType())
                .databaseUrl(req.getDatabaseUrl())
                .databasePost(req.getDatabasePost())
                .databaseName(req.getDatabaseName())
                .userName(req.getUserName())
                .userPwd(req.getUserPwd())
                .initCount(req.getInitCount())
                .maxCount(req.getMaxCount())
                .maxTime(req.getMaxTime())
                .maxFrequency(req.getMaxFrequency())
                .build();
    }





















}
