package com.muyu.etl.data.access.domain.resp;

import com.muyu.etl.data.access.domain.DataSource;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/8/19 19:12
 * @注释
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
@Tag(name = "数据源输出信息",description = "查询数据源信息需要输出的字段")
public class DataSourceResp {
    /**
     *      主键
     */
    @Schema(type = "String",defaultValue = "1",description = "数据源主键")
    private Long   id; /**
     *      数据源类型
     */
    @Schema(type = "String",defaultValue = "MySQL",description = "数据信息来源的信息名称")
    private String   databaseType;
    /**
     *      数据源名称
     */
    @Schema(type = "String",defaultValue = "cloud-app",description = "数据源的来源的名称")
    private String databaseFormName;
    /**
     *      数据来源地址
     */
    @Schema(type = "String",defaultValue = "127.0.0.1",description = "数据来源地址")
    private String databaseUrl;
    /**
     *      来源地址端口号
     */
    @Schema(type = "String",defaultValue = "3306",description = "来源地址端口号")
    private String databasePost;
    /**
     *      数据库名称
     */
    @Schema(type = "String",defaultValue = "cloud-server",description = "数据库名称")
    private String databaseName;
    /**
     * 表名 t_table
     */
    @Schema(type = "String",defaultValue = "t_student",description = "表名称")
    private String tableName;
    /**
     * 字段名
     */
    @Schema(type = "String",defaultValue = "datasource_id,database_name",description = "字段名")
    private String tableColumn;
    /**
    /**
     *      数据库登录名
     */
    @Schema(type = "String",defaultValue = "root",description = "数据库登录名")
    private String userName;
    /**
     *      数据库登录密码
     */
    @Schema(type = "String",defaultValue = "wuzuxiaoniu@123.",description = "数据库登录密码")
    private String userPwd;
    /**
     *      数据源状态(1启用,2禁用)
     */
    @Schema(type = "String",defaultValue = "1",description = "数据源状态")
    private String status;

    @Schema(type = "String",defaultValue = "1",description = "数据源状态")

    /** 驱动 com.mysql.cj.jdbc.Driver */
    private String driverName;
    @Schema(type = "Integer",defaultValue = "com.mysql.cj.jdbc.Driver",description = "驱动")

    /** 初始连接数量 */
    private Integer initCount;
    @Schema(type = "Integer",defaultValue = "1",description = "最大连接数量")

    /** 最大连接数量 */
    private Integer maxCount;
    @Schema(type = "Integer",defaultValue = "1",description = "最大等待时间")

    /** 最大等待时间 */
    private Integer maxTime;
    @Schema(type = "Integer",defaultValue = "1",description = "最大等待次数")

    /** 最大等待次数 */
    private Integer maxFrequency;

    public static DataSourceResp dataSourceRespBuild(DataSource dataSource){
        return DataSourceResp.builder()
                .id(dataSource.getId())
                .databaseName(dataSource.getDatabaseName())
                .databaseType(dataSource.getDatabaseType())
                .databaseFormName(dataSource.getDatabaseFormName())
                .databaseUrl(dataSource.getDatabaseUrl())
                .databasePost(dataSource.getDatabasePost())
                .databaseName(dataSource.getDatabaseName())
                .userName(dataSource.getUserName())
                .userPwd(dataSource.getUserPwd())
                .status(dataSource.getStatus())
                .driverName(dataSource.getDriverName())
                .initCount(dataSource.getInitCount())
                .maxCount(dataSource.getMaxCount())
                .maxTime(dataSource.getMaxTime())
                .maxFrequency(dataSource.getMaxFrequency())
                .build();
    }




































}
