package com.muyu.etl.data.access.remote;

import com.muyu.common.core.constant.ServiceNameConstants;
import com.muyu.common.core.domain.Result;
import com.muyu.etl.data.access.domain.req.EtlDataSqlReq;
import com.muyu.etl.domain.DataStructure;
import com.muyu.etl.data.access.remote.factory.RemoteEtlDataBackFactory;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/9/1 9:27
 * @注释
 */
@FeignClient(contextId = "remoteEtlDataService",
        value = ServiceNameConstants.DATA_SERVICE,
        path = "etlData",
        fallbackFactory = RemoteEtlDataBackFactory.class)
public interface RemoteEtlDataService {

    /**
     * 远调ktly格式数据
     */
    @PostMapping("/selEtlData")
    Result<List<List<DataStructure>>> selEtlData(@RequestBody EtlDataSqlReq etlDataSqlReq);

    /**
     * 根据基础表ID和SQL语句查询数据
     *
     * @param etlDataSqlReq 基础表ID和sql语句
     * @return DataValue{kltv}
     */
    @PostMapping("/addTableValue")
    Result addTableValue(@RequestBody EtlDataSqlReq etlDataSqlReq);

    /**
     * 根据基础表ID和SQL语句查询数据总数
     * @param etlDataSqlReq 基础表ID和sql语句
     * @return Integer
     */
    @PostMapping("/getTableValueTotal")
    Result getTableValueTotal(@RequestBody EtlDataSqlReq etlDataSqlReq);
}
