package com.muyu.etl.data.access.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.etl.data.access.domain.DataAnalysis;
import com.muyu.etl.data.access.service.DataAnalysisService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.log4j.Log4j2;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/8/28 19:18
 * @注释
 */
@Log4j2
@RestController
@RequestMapping("/dataAnalysis")
@Tag(name = "数据资产结构",description = "根据对应的表名称查询数据资产结构")
public class DataAnalysisController extends BaseController{

    @Resource
    private DataAnalysisService dataAnalysisService;

    @Operation(summary = "数据资产结构",description = "根据表的ID查询表中数据资产结构")
    @PostMapping("/findDataAnalysisByTableId/{id}")
    public Result<List<DataAnalysis>> findDataAnalysisByTableId(@PathVariable("id") Long id){

        List<DataAnalysis> list = dataAnalysisService.findStructureByTableId(id);
        return Result.success(list,"操作成功");
    }

    @RequiresPermissions(value = "data:assetdisplay:list")
    @Operation(summary = "数据资产展示",description = "根据表的ID查询表中数据资产展示")
    @GetMapping("/{id}")
    public Result<List<DataAnalysis>> findDataAnalysisById(@PathVariable("id") Long id){
     return Result.success(dataAnalysisService.getTableById(id));
    }


}
