package com.muyu.etl.data.access.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.etl.data.access.domain.req.EtlDataSqlReq;
import com.muyu.etl.domain.DataStructure;
import com.muyu.etl.data.access.service.DataStructureService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.log4j.Log4j2;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/8/29 18:47
 * @注释
 */
@RestController
@RequestMapping("/etlData")
@Log4j2
@Tag(name = "数据转换控制中心",description = "进行对数据源连接,查询等相关操作")
public class DataStructureController extends BaseController {

    @Resource
    private DataStructureService dataStructureService;



    @Operation(summary = "查询etl所需的ktlv格式的字段",description = "根据库表名,字段名查询表字段,再进行数据转换为ktlv格式")
    @PostMapping("/selEtlData")
    public Result<List<List<DataStructure>>> selDataStructure(@RequestBody EtlDataSqlReq etlDataSqlReq) {
        long l = System.currentTimeMillis();
        Result<List<List<DataStructure>>> success = Result.success(dataStructureService.selDataStructure(etlDataSqlReq));
        long l1 = System.currentTimeMillis();
        log.info("查询耗时---》{}s",l1-l);
        return success;
    }

    /**
     * 获取表中的数据值前台调用
     * @param basicId 响应参数
     * @param tableName 响应参数
     * @return 返回结果
     */
    @PostMapping("/findTableValueList/{basicId}/{tableName}")
    @Operation(summary = "获取表中的数据值前台调用",
            description = "获取表中的数据值前台调用")
    public Result<List<DataStructure>> findTableValueByTableName(@PathVariable("basicId") Long basicId,@PathVariable("tableName") String tableName){
        List<DataStructure> list = dataStructureService.findTableValueByTableName(basicId,tableName);
        return Result.success(list);
    }

    /**
     * 根据基础表ID和SQL语句查询数据总数
     * @param etlDataSqlReq 基础表ID和sql语句
     * @return Integer
     */
    @PostMapping("/getTableValueTotal")
    @Operation(summary = "根据基础表ID和SQL语句查询数据总数", description = "根据基础表ID和SQL语句查询数据总数")
    public Result getTableValueTotal(@RequestBody EtlDataSqlReq etlDataSqlReq) {
        Integer i = dataStructureService.getTableValueTotal(etlDataSqlReq);
        return Result.success(i);
    }

    /**
     * 根据基础表ID和SQL语句查询数据
     *
     * @param etlDataSqlReq 基础表ID和sql语句
     * @return DataValue{kltv}
     */
    @PostMapping("/addTableValue")
    @Operation(summary = "根据基础表ID和SQL语句新增数据", description = "根据基础表ID和SQL语句新增数据")
    public Result addTableValue(@RequestBody EtlDataSqlReq etlDataSqlReq) {
        Integer i = dataStructureService.addTableValue(etlDataSqlReq);
        return Result.success(i);
    }

}
