package com.muyu.etl.data.access.controller;

import cn.hutool.core.bean.BeanUtil;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.etl.data.access.domain.EtlTableUserPermission;
import com.muyu.etl.data.access.domain.req.EtlTableUserPermissionReq;
import com.muyu.etl.data.access.service.EtlTableUserPermissionService;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/9/1 14:53
 * @注释
 */
@RestController
@RequestMapping("/permission")
public class EtlTableUserPermissionController extends BaseController {

    @Resource
    private EtlTableUserPermissionService etlTableUserPermissionService;


    /**
     * 查询资产赋权用户信息
     * @param req 响应参数
     * @return 返回结果
     */
    @Log()
    @PostMapping("/findUserIdList")
    @Operation(summary = "查询资产赋权用户信息",
            description = "查询资产赋权用户信息")
    public Result findUserIdList(@RequestBody EtlTableUserPermissionReq req){
        List<Long> list = etlTableUserPermissionService.findUserIdList(req);
        return Result.success(list);
    }



    /**
     * 添加用户权限的信息
     * @param req 相应参数
     * @return 返回结果
     */
    @PostMapping("/addUserpermission")
    @Operation(summary = "添加用户权限的信息",
            description = "添加用户权限的信息")
    public Result addUserAssetImpower(@RequestBody EtlTableUserPermissionReq req){
        EtlTableUserPermission etlTableUserPermission = new EtlTableUserPermission();
        etlTableUserPermission.setUserId(req.getUserId());
        etlTableUserPermission.setTableId(req.getTableId());
        etlTableUserPermission.setBasicId(req.getBasicId());
        BeanUtil.copyProperties(req, etlTableUserPermission);
        boolean save = etlTableUserPermissionService.save(etlTableUserPermission);
        return save?Result.success():Result.error();
    }

    /**
     * 删除用户权限的信息
     * @param req 响应参数
     * @return  返回结果
     */
    @PostMapping("/delUserpermission")
    @Operation(summary = "删除用户权限的信息",
            description = "删除用户权限的信息")
    public Result delUserAssetImpower(@RequestBody EtlTableUserPermissionReq req){
        int i = etlTableUserPermissionService.delUserAssetAccredit(req);
        return i>0?Result.success():Result.error();
    };

    /**
     * 查询资产赋权部门的信息
     * @param req 响应参数
     * @return 返回结果
     */
    @PostMapping("/findDeptIdList")
    @Operation(summary = "查询资产赋权部门的信息",
            description = "查询资产赋权部门的信息")
    public Result findDeptIdList(@RequestBody EtlTableUserPermissionReq req){
        List<Long> list = etlTableUserPermissionService.findDeptIdList(req);
        return Result.success(list);
    }

    /**
     * 添加部门权限的信息
     * @param req 响应参数
     * @return 返回结果
     */
    @PostMapping("/addDeptpermission")
    @Operation(summary = "添加部门权限的信息",
            description = "添加部门权限的信息")
    public Result addDeptAssetImpower(@RequestBody EtlTableUserPermissionReq req){
        EtlTableUserPermission etlTableUserPermission = new EtlTableUserPermission();
        etlTableUserPermission.setDeptId(req.getDeptId());
        etlTableUserPermission.setTableId(req.getTableId());
        etlTableUserPermission.setBasicId(req.getBasicId());
        boolean save = etlTableUserPermissionService.save(etlTableUserPermission);
        return save?Result.success():Result.error();
    }

    /**
     * 删除部门权限的信息
     * @param req 响应参数
     * @return  返回结果
     */
    @PostMapping("/delDeptpermission")
    @Operation(summary = "删除部门权限的信息",
            description = "删除部门权限的信息")
    public Result delDeptAssetImpower(@RequestBody EtlTableUserPermissionReq req){
        int i = etlTableUserPermissionService.delDeptAssetAccredit(req);
        return i>0?Result.success():Result.error();
    };


}
