package com.muyu.etl.data.access.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.etl.data.access.data.access.client.config.DatabaseConnectionPool;
import com.muyu.etl.data.access.mapper.DataStructureMapper;

import com.muyu.etl.data.access.domain.req.EtlDataSqlReq;
import com.muyu.etl.domain.DataStructure;
import com.muyu.etl.data.access.service.DataSourceService;
import com.muyu.etl.data.access.service.DataStructureService;
import com.muyu.etl.enums.DataType;
import com.zaxxer.hikari.HikariDataSource;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.sql.*;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.*;

import static com.muyu.etl.data.access.pool.base.BaseConfig.SELECTALL;
import static java.util.regex.Pattern.compile;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/8/29 18:46
 * @注释
 */
@Log4j2
@Service
public class DataStructureServiceImpl extends ServiceImpl<DataStructureMapper, DataStructure> implements DataStructureService {


    @Resource
    private DataStructureMapper dataStructureMapper;

    @Resource
    private DataSourceService dataSourceService;

    @Resource
    private DatabaseConnectionPool databaseConnectionPool;

    private static String extractTableName(String sql) {
        // 这个正则表达式用于匹配FROM后面直到第一个空白字符或SQL语句结束的表名
        String regex = "FROM\\s+([a-zA-Z_][a-zA-Z0-9_]*)";
        java.util.regex.Pattern pattern = compile(regex);
        java.util.regex.Matcher matcher = pattern.matcher(sql);

        if (matcher.find()) {
            return matcher.group(1); // 返回匹配到的第一个组
        }
        return null; // 如果没有找到匹配项，则返回null
    }


    @Override
    public List<List<DataStructure>> selDataStructure(EtlDataSqlReq etlDataSqlReq) {
        //根据数据源ID获取数据源信息
        ConcurrentHashMap<Integer, DataStructure> map = new ConcurrentHashMap<>();
        //初始化一个列表,用于存储数据值对象
        List<List<DataStructure>> list = new ArrayList<>();
        HikariDataSource hikariDataSource = databaseConnectionPool.get(etlDataSqlReq.getBasicId());
        Connection conn = null;
        try {
            conn = hikariDataSource.getConnection();
            //准备SQL查询
            Statement statement = conn.createStatement();
            ResultSet resultSet = statement.executeQuery(etlDataSqlReq.getSql());
            //获取元数据
            ResultSetMetaData metaData = resultSet.getMetaData();
            //获取列的数量
            int columnCount = metaData.getColumnCount();
            //遍历每一行数据
            while (resultSet.next()) {
                List<DataStructure> dataStructures = new ArrayList<>();
                // 提交任务给线程池
                for (int i = 1; i <= columnCount; i++) {
                    if (resultSet.isFirst()) {
                        String columnTypeName = metaData.getColumnTypeName(i);
                        DatabaseMetaData metaDataTwo = conn.getMetaData();
                        ResultSet columns = metaDataTwo.getColumns(null, null, metaData.getTableName(i), metaData.getColumnName(i));
                        String remarks = null;
                        while (columns.next()) {
                            remarks = columns.getString("REMARKS");
                        }
                        DataStructure build = DataStructure.builder()
                                .key(metaData.getColumnName(i))
                                .label(remarks)
                                .value(resultSet.getObject(i, DataType.getTargetClass(columnTypeName)))
                                .type(DataType.getDataType(columnTypeName))
                                .build();
                        dataStructures.add(build);
                        map.put(i, build);
                    } else {
                        DataStructure build = DataStructure.builder()
                                .key(metaData.getColumnName(i))
                                .label(map.get(i).getLabel())
                                .value(resultSet.getObject(i, map.get(i).getType().getTargetType()))
                                .type(map.get(i).getType())
                                .build();
                        dataStructures.add(build);
                    }
                }
                list.add(dataStructures);
            }
        }catch (Exception e) {
            throw new RuntimeException(e);
        }finally {
            databaseConnectionPool.returnConnection(conn,hikariDataSource);
        }
        return list;
    }

    /**
     * 获取表中数据值供前台
     *
     * @param basicId 响应参数
     * @param tableName 响应参数
     * @return 返回结果
     * <p>
     * 原代码
     */
    private static final Integer PAGE_SIZE = 1;

    @Override
    public List<DataStructure> findTableValueByTableName(Long basicId, String tableName) {

        ConcurrentHashMap<Integer, DataStructure> map = new ConcurrentHashMap<>();

        ArrayList<DataStructure> dataValues = new ArrayList<>();
        HikariDataSource hikariDataSource = databaseConnectionPool.get(basicId);
        Connection conn = null;
        try {
            conn = hikariDataSource.getConnection();
            // 准备SQL查询语句
            PreparedStatement preparedStatement = conn.prepareStatement(SELECTALL + tableName + " LIMIT " + PAGE_SIZE);
            // 执行查询，获取结果集
            ResultSet resultSet = preparedStatement.executeQuery();
            // 获取结果集的元数据，用于获取列的数量和类型等信息
            ResultSetMetaData metaData = resultSet.getMetaData();
            // 获取列的数量
            int columnCount = metaData.getColumnCount();

            // 遍历结果集中的每一行数据
            while (resultSet.next()) {
                // 遍历每一列
                for (int i = 1; i <= columnCount; i++) {
                    if (resultSet.isFirst()) {
                        // 获取当前列的类型名称
                        String columnTypeName = metaData.getColumnTypeName(i);
                        // 获取数据库的元数据对象
                        DatabaseMetaData metaDataColumns = conn.getMetaData();
                        // 查询数据库元数据，获取当前列的备注信息
                        ResultSet columns = metaDataColumns.getColumns(null, null, metaData.getTableName(i), metaData.getColumnName(i));
                        String remarks = null;
                        // 遍历备注信息的结果集
                        while (columns.next()) {
                            // 获取当前字段的备注信息
                            remarks = columns.getString("REMARKS");
                            // 记录日志，显示字段的备注信息
                            log.info("字段备注:" + remarks);
                        }
                        // 构建数据值对象，包含列名、备注、值、类型等信息
                        DataStructure build = DataStructure.builder()
                                .key(metaData.getColumnName(i))// 当前列的名称
                                .label(remarks)// 当前列的备注信息
                                .value(resultSet.getObject(i, DataType.getTargetClass(columnTypeName)))// 当前列的值，类型转换
                                .type(DataType.getDataType(columnTypeName))// 当前列的类型，转换为字符串表示
                                .build();
                        dataValues.add(build);
                        map.put(i, build);
                    } else {
                        DataStructure build = DataStructure.builder()
                                .key(metaData.getColumnName(i))// 当前列的名称
                                .label(map.get(i).getLabel())// 当前列的备注信息
                                .value(resultSet.getObject(i, map.get(i).getType().getTargetType()))// 当前列的值，类型转换
                                .type(map.get(i).getType())// 当前列的类型，转换为字符串表示
                                .build();
                        dataValues.add(build);
                    }
                }
            }
        } catch (SQLException e) {
            // 如果发生SQL异常，抛出运行时异常
            throw new RuntimeException(e);
        }finally {
            databaseConnectionPool.returnConnection(conn,hikariDataSource);
        }
        // 返回包含数据值的列表
        return dataValues;
    }

    @Override
    public Integer getTableValueTotal(EtlDataSqlReq etlDataSqlReq) {
        HikariDataSource hikariDataSource = databaseConnectionPool.get(etlDataSqlReq.getBasicId());
        Connection conn = databaseConnectionPool.getConn(hikariDataSource);
        try {
            Statement statement = conn.createStatement();
            ResultSet resultSet = statement.executeQuery(etlDataSqlReq.getSql());
            if (resultSet.next()) {
                return resultSet.getInt(1);
            }
        } catch (SQLException e) {
            throw new RuntimeException(e);
        }finally {
            databaseConnectionPool.returnConnection(conn,hikariDataSource);
        }
        return 0;
    }

    @Override
    public Integer addTableValue(EtlDataSqlReq etlDataSqlReq) {
        HikariDataSource hikariDataSource = databaseConnectionPool.get(etlDataSqlReq.getBasicId());
        Connection conn = databaseConnectionPool.getConn(hikariDataSource);
        try {
            PreparedStatement preparedStatement = conn.prepareStatement(etlDataSqlReq.getSql());
            return preparedStatement.executeUpdate();
        } catch (SQLException e) {
            throw new RuntimeException(e);
        }finally {
            databaseConnectionPool.returnConnection(conn,hikariDataSource);
        }
    }
}



