package com.muyu.etl.data.access.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.etl.data.access.mapper.EtlTableUserPermissionMapper;
import com.muyu.etl.data.access.service.EtlTableUserPermissionService;
import com.muyu.etl.data.access.domain.EtlTableUserPermission;
import com.muyu.etl.data.access.domain.req.EtlTableUserPermissionReq;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/9/1 14:53
 * @注释
 */
@Service
public class EtlTableUserPermissionServiceImpl extends ServiceImpl<EtlTableUserPermissionMapper, EtlTableUserPermission> implements EtlTableUserPermissionService {

    @Resource
    private EtlTableUserPermissionMapper etlTableUserPermissionMapper;

    /**
     * 传入用户ID，获取该用户授权的所有表ID和基础ID
     * @param userId 响应参数
     * @return 返回结果
     */
    @Override
    public List<EtlTableUserPermission> findTableIdAndBasicIdByUserId(Long userId) {
        List<EtlTableUserPermission> list = etlTableUserPermissionMapper.findTableIdAndBasicIdByUserId(userId);
        return list;
    }

    /**
     * 传入部门ID，获取该部门下所有授权的表ID和基础ID
     * @param deptId 响应参数
     * @return 返回结果
     */
    @Override
    public List<EtlTableUserPermission> findTableIdAndBasicIdByDeptId(Long deptId) {
        List<EtlTableUserPermission> list = etlTableUserPermissionMapper.findTableIdAndBasicIdByDeptId(deptId);
        return list;
    }

    /**
     * 查询资产赋权用户信息
     * @param req 响应参数
     * @return 返回结果
     */
    @Override
    public List<Long> findUserIdList(EtlTableUserPermissionReq req) {
        List<Long> userIdList = etlTableUserPermissionMapper.findUserIdList(req);
        return userIdList;
    }
    /**
     * 删除用户权限方法
     * @param req 响应参数
     * @return  返回结果
     */
    @Override
    public int delUserAssetAccredit(EtlTableUserPermissionReq req) {
        LambdaQueryWrapper<EtlTableUserPermission> queryWrapper = new LambdaQueryWrapper<>();
        if (null==req.getBasicId()){
            queryWrapper.eq(EtlTableUserPermission::getUserId,req.getUserId())
                    .eq(EtlTableUserPermission::getTableId,req.getTableId());
        }else if (null==req.getTableId()){
            queryWrapper.eq(EtlTableUserPermission::getUserId,req.getUserId())
                    .eq(EtlTableUserPermission::getBasicId,req.getBasicId());
        }

        int delete = etlTableUserPermissionMapper.delete(queryWrapper);
        return delete;
    }
    /**
     * 查询资产赋权部门信息
     * @param req 响应参数
     * @return 返回结果
     */
    @Override
    public List<Long> findDeptIdList(EtlTableUserPermissionReq req) {
        List<Long> deptIdList = etlTableUserPermissionMapper.findDeptIdList(req);
        return deptIdList;
    }
    /**
     * 删除部门权限方法
     * @param req 响应参数
     * @return  返回结果
     */
    @Override
    public int delDeptAssetAccredit(EtlTableUserPermissionReq req) {
        LambdaQueryWrapper<EtlTableUserPermission> queryWrapper = new LambdaQueryWrapper<>();
        if (null==req.getBasicId()){
            queryWrapper.eq(EtlTableUserPermission::getDeptId,req.getDeptId())
                    .eq(EtlTableUserPermission::getTableId,req.getTableId());
        }else if (null==req.getTableId()){
            queryWrapper.eq(EtlTableUserPermission::getDeptId,req.getDeptId())
                    .eq(EtlTableUserPermission::getBasicId,req.getBasicId());
        }

        int delete = etlTableUserPermissionMapper.delete(queryWrapper);
        return delete;
    }
}
